@@ -61,6 +61,18 @@ let get_version = lazy (
 )
 let version () = Lazy.force get_version
 
+let probe_server_parameter name =
+  let list_options =
+    if String.length name = 2 &&
+         name.[0] = '-' &&
+         name.[1] <> '-' then
+      "--short-options"
+    else
+      "--long-options" in
+  let regex = sprintf "^%s$" name in
+  let cmd = sprintf "nbdkit %s | grep -sq %s" list_options (quote regex) in
+  Sys.command cmd = 0
+
 let probe_plugin name =
   let cmd = sprintf "nbdkit %s --version >/dev/null 2>&1" (quote name) in
   Sys.command cmd = 0
@@ -82,6 +94,7 @@ let probe_filter_parameter name regex =
 
 type cmd = {
   plugin : string;
+  name : string option;
   mutable filters : string list;
   mutable args : (string * string) list; (* stored reversed *)
   mutable env : (string * string) list;
@@ -91,8 +104,9 @@ type cmd = {
   verbose : bool;
 }
 
-let create ?(quiet = false) plugin = {
+let create ?(quiet = false) ?name plugin = {
   plugin;
+  name;
   filters = [];
   args = [];
   env = [ "LANG", "C" ];
@@ -133,6 +147,17 @@ let run_unix socket cmd =
   in
 
   add_arg "nbdkit";
+
+  (match cmd.name with
+   | None -> ()
+   | Some name ->
+      (* --name parameter should be first, so it appears early in 'ps'. *)
+      if probe_server_parameter "--name" then (
+        add_arg "--name";
+        add_arg name
+      )
+  );
+
   add_arg "--exit-with-parent";
   add_arg "--foreground";
   add_arg "--pidfile"; add_arg pidfile;
